Module source_info

Module source_info 

Structs

SourceInfo
Additional information about a node which is not needed at runtime, but may be useful for documentation or debugging purposes. This is kept in a separate struct to make sure it doesn’t accidentally get included in contexts where it is not needed. The CodeGeneratorRequest includes this information in a separate array.
SourceInfoMember