Structs
- Source
Info - Additional information about a node which is not needed at runtime, but may be useful for
documentation or debugging purposes. This is kept in a separate struct to make sure it
doesn’t accidentally get included in contexts where it is not needed. The
CodeGeneratorRequestincludes this information in a separate array. - Source
Info Member